#
# spec file for package python-WTForms
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
Name:           python-WTForms
Version:        2.1
Release:        lp150.1.3
Summary:        A flexible forms validation and rendering library for Python web development
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://wtforms.simplecodes.com/
Source:         https://files.pythonhosted.org/packages/source/W/WTForms/WTForms-%{version}.zip
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%if %{with test}
BuildRequires:  python3-Babel
BuildRequires:  python3-Django
BuildRequires:  python3-SQLAlchemy
BuildRequires:  python3-python-dateutil
%endif
Recommends:     python-Babel
Recommends:     python-Django
Recommends:     python-SQLAlchemy
Recommends:     python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
WTForms is a forms validation and rendering library for Python web development.
With WTForms, form field HTML can be generated and be customized with templates.
This allows to maintain separation of code and presentation, and keep those parameters out of Python code.
Because of this loose coupling, any template engine may be used for this.

%package -n %{name}-doc
Summary:        Documentation for WTForms
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description -n %{name}-doc
Documentation for WTForms, which is a forms validation and rendering library for Python web development.

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
Provides:       %{name}-lang-all = %{version}

%description lang
Provides translations to the package %{name}

%prep
%setup -q -n WTForms-%{version}
sed -i "s/\r//" CHANGES.rst docs/html/_static/jquery.js # Fix wrong EOL-encoding
rm -rf docs/html/.buildinfo # Remove junk

%build
%python_build

%install
%python_install
%find_lang wtforms
%python_expand grep -F "%{$python_sitelib}" wtforms.lang > wtforms_%{$python_bin_suffix}.lang
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS.txt CHANGES.rst LICENSE.txt README.md
%{python_sitelib}/*
%exclude %{python_sitelib}/wtforms/locale

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc docs/html

%if %have_python2 && ! 0%{?skip_python2}
%files -n %{python2_prefix}-WTForms-lang -f wtforms_%{python2_bin_suffix}.lang
%defattr(-,root,root,-)
%{python2_sitelib}/wtforms/locale
%endif

%if %have_python2 && ! 0%{?skip_python3}
%files -n %{python3_prefix}-WTForms-lang -f wtforms_%{python3_bin_suffix}.lang
%defattr(-,root,root,-)
%{python3_sitelib}/wtforms/locale
%endif

%changelog
* Sat Sep  2 2017 jengelh@inai.de
- Don't let description assume any particular user.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 2.1
  * Added `render_kw` to allow default rendering time options.
  * Updated / added a number of localizations
  * Updated docs
  * Allow widgets to set flags
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 2.0.2:
  * Added more localizations and updated some
  * Validators for email and URL can validate IDNA-encoded domain
    names and new TLDs
  * Better DeprecationWarnings
  * Support localization files in /usr/share/locale (for distro
    packaging)
- additional changes from version 2.0.1
  * Released July 1, 2014
  * Update wheel install to conditionally install ordereddict for
    python 2.6
  * Doc improvements
- additional changes from version 2.0
  * Add new class Meta paradigm for much more powerful
    customization of WTForms
  * Move i18n into core. Deprecate wtforms.ext.i18n
  * Move CSRF into core. Deprecate wtforms.ext.csrf
  * Fix issue rendering SelectFields with value=True
  * Make DecimalField able to use babel locale-based number
    formatting
  * Drop Python 3.2 support (Python3 support for 3.3+ only)
  * passing attr=False to WTForms widgets causes the value to be
    ignored
  * Unique validator in wtforms.ext.sqlalchemy has been removed
- add new dependency python-ordereddict for SLE11
- update the list of files to fix end of line encoding
- use %%find_lang for the lang subpackage: paths changed upstream
- run the tests during build
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.md: changed upstream
* Thu Apr 10 2014 aboe76@gmail.com
- Updated to version 1.0.5:
  + Fix a bug in validators which causes translations to happen once then clobber any future translations.
  + ext.sqlalchemy / ext.appengine: minor cleanups / deprecation.
  + Allow blank string and the string 'false' to be considered false values for BooleanField (configurable). This is technically a breaking change, but it is not likey to affect the majority of users adversely.
  + ext.i18n form allows passing LANGUAGES to the constructor.
- from version 1.0.4:
  + Add widgets and field implementations for HTML5 specialty input types.
  + ext.appengine: Add NDB support.
  + Add translations: Korean, Traditional Chinese
- cleaned up spec file:
  + created a doc package
  + rpmlint lang warnings script taken from python-wxWidgets
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Apr 14 2013 p.drouand@gmail.com
- Update to version 1.0.3
  + Tests complete in python 3.2/3.3.
  + Localization for ru, fr.
  + Minor fixes in documentation for clarity.
  + FieldList now can take validators on the entire FieldList.
  + ext.sqlalchemy model_form:
  * Fix issue with QuerySelectField
  * Fix issue in ColumnDefault conversion
  * Support Enum type
  + Field class now allows traversal in Django 1.4 templates.
- Initial python3 support
* Tue Sep 27 2011 saschpe@suse.de
- Update to version 0.6.3:
  * Documentation: Substantial documentation improvements, including adding
    Crash Course as a sphinx document.
  * ext.django: QuerySetSelectField (and ModelSelectField) now accept get_label
    similar to sqlalchemy equivalents.
  * ext.appengine:
    + model_form fixes: FloatField(#50), TimeField, DateTimeField(#55)
    + ReferencePropertyField: now properly stores model object, not key. (#48)
- Changes from version 0.6.2:
  * ext.appengine: various field fixes (#34, #48), model_form changes (#41)
  * Fix issue in Optional with non-string input.
  * Make numeric fields more consistent.
  * Tests: Improve test coverage substantially.
- Recommend python-django, python-SQLAlchemy & python-google-appengine,
  WTForms provides optional integration for each
- Package documentation
* Tue Oct 26 2010 kianseong@gmail.com
- Further changes to spec based on review
* Tue Oct 26 2010 kianseong@gmail.com
- Changes to spec file based on review
* Tue Oct 26 2010 kianseong@gmail.com
- New package wtforms
